@@ -4,5 +4,5 @@ from aiotinyrpc.dispatch import RPCDispatcher
 class FluxVaultExtensions(RPCDispatcher):
     """Wrapper to keep dispatcher internal to FluxVault"""
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
